==> nextcloud-app-calendar-1%3A2.3.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/nn_NO.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s has lagt ut  kalenderen »%s«",
    "Hello," : "Hallo,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Me vil sei ifrå om at %shar lagt ut kalenderen »%s«.",
    "Open »%s«" : "Opna »%s«",
    "Cheers!" : "Tudelu!",
    "Calendar" : "Kalender",
    "Today" : "I dag",
    "Day" : "Dag",
    "Week" : "Veke",
    "Month" : "Månad",
    "Download" : "Last ned",
    "Delete" : "Slett",
    "Share link" : "Del lenkje",
    "can edit" : "kan endra",
    "New calendar" : "Ny kalender",
    "Cancel" : "Avbryt",
    "Actions" : "Handlingar",
    "Email" : "E-post",
    "Unknown" : "Ukjend",
    "never" : "aldri",
    "after" : "etter",
    "Repeat" : "Gjenta",
    "Monday" : "Måndag",
    "Summary" : "Oppsumering",
    "More" : "Meir",
    "Save" : "Lagre",
    "Update" : "Oppdater",
    "Personal" : "Personleg",
    "Details" : "Detaljar",
    "Attendees" : "Deltakarar",
    "Reminders" : "Påminningar",
    "Close" : "Lukk",
    "Daily" : "Kvar dag",
    "Weekly" : "Kvar veke",
    "When shared show full event" : "Når delt, vis heile hendinga",
    "When shared show only busy" : "Når delt, vis berre oppteken",
    "When shared hide this event" : "Når delt, gøym denne hendinga",
    "Location" : "Stad",
    "Description" : "Skildring",
    "Status" : "Status",
    "Confirmed" : "Stadfesta",
    "Tentative" : "Førebels",
    "Mail" : "Post",
    "Global" : "Global"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1%3A3.3.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/nn_NO.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s has lagt ut  kalenderen »%s«",
    "Hello," : "Hallo,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Me vil sei ifrå om at %shar lagt ut kalenderen »%s«.",
    "Open »%s«" : "Opna »%s«",
    "Cheers!" : "Tudelu!",
    "Prepare for %s" : "Klargjer for %s",
    "Calendar" : "Kalender",
    "New event" : "Ny hending",
    "Today" : "I dag",
    "Day" : "Dag",
    "Week" : "Veke",
    "Month" : "Månad",
    "Edit" : "Rediger",
    "Delete" : "Slett",
    "Export" : "Eksporter",
    "Share link" : "Del lenkje",
    "can edit" : "kan endra",
    "New calendar" : "Ny kalender",
    "Name" : "Namn",
    "Deleted" : "Sletta",
    "Restore" : "Gjenopprett",
    "Delete permanently" : "Slett for godt",
    "Empty trash bin" : "Tøm søppel korg",
    "Cancel" : "Avbryt",
    "List view" : "Liste visning",
    "Actions" : "Handlingar",
    "Location" : "Stad",
    "Description" : "Skildring",
    "to" : "til",
    "Add" : "Legg til",
    "Monday" : "Måndag",
    "Tuesday" : "Tysdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Laurdag",
    "Sunday" : "Søndag",
    "Save" : "Lagre",
    "Update" : "Oppdater",
    "Your email address" : "Di epost-adresse",
    "Email" : "E-post",
    "Unknown" : "Ukjend",
    "Tentative" : "Førebels",
    "Send email" : "Send e-post",
    "Repeat" : "Gjenta",
    "never" : "aldri",
    "after" : "etter",
    "last" : "siste",
    "Room type" : "Romtype",
    "More" : "Meir",
    "Global" : "Global",
    "Personal" : "Personleg",
    "Details" : "Detaljar",
    "Attendees" : "Deltakarar",
    "Close" : "Lukk",
    "Daily" : "Kvar dag",
    "Weekly" : "Kvar veke",
    "Next" : "Neste",
    "Year" : "År",
    "Meeting room" : "Møterom",
    "Other" : "Anna",
    "When shared show full event" : "Når delt, vis heile hendinga",
    "When shared show only busy" : "Når delt, vis berre oppteken",
    "When shared hide this event" : "Når delt, gøym denne hendinga",
    "Status" : "Status",
    "Confirmed" : "Stadfesta",
    "Talk" : "Prat",
    "Mail" : "Post",
    "Birthday" : "Bursdag"
},
"nplurals=2; plural=(n != 1);");
